@@ -1,7 +1,7 @@
 '''
 Salt's pluggable authentication system
 
-This sysetm allows for authentication to be managed in a module pluggable way
+This system allows for authentication to be managed in a module pluggable way
 so that any external authentication system can be used inside of Salt
 '''
 
@@ -12,7 +12,7 @@ so that any external authentication system can be used inside of Salt
 # 5. Cache auth token with relative data opts['token_dir']
 # 6. Interface to verify tokens
 
-# Import Python libs
+# Import python libs
 import os
 import hashlib
 import time
@@ -20,7 +20,7 @@ import logging
 import random
 import getpass
 
-# Import Salt libs
+# Import salt libs
 import salt.loader
 import salt.utils
 import salt.payload
@@ -43,10 +43,10 @@ class LoadAuth(object):
         Return the primary name associate with the load, if an empty string
         is returned then the load does not match the function
         '''
-        if not 'eauth' in load:
+        if 'eauth' not in load:
             return ''
         fstr = '{0}.auth'.format(load['eauth'])
-        if not fstr in self.auth:
+        if fstr not in self.auth:
             return ''
         fcall = salt.utils.format_call(self.auth[fstr], load)
         try:
@@ -56,15 +56,15 @@ class LoadAuth(object):
 
     def __auth_call(self, load):
         '''
-        Return the token and set the cache data for use 
+        Return the token and set the cache data for use
 
         Do not call this directly! Use the time_auth method to overcome timing
         attacks
         '''
-        if not 'eauth' in load:
+        if 'eauth' not in load:
             return False
         fstr = '{0}.auth'.format(load['eauth'])
-        if not fstr in self.auth:
+        if fstr not in self.auth:
             return False
         fcall = salt.utils.format_call(self.auth[fstr], load)
         try:
@@ -76,7 +76,6 @@ class LoadAuth(object):
             err = 'Authentication module threw an exception: {0}'.format(exc)
             log.critical(err)
             return False
-        return False
 
     def time_auth(self, load):
         '''
@@ -117,7 +116,7 @@ class LoadAuth(object):
                  'name': fcall['args'][0],
                  'eauth': load['eauth'],
                  'token': tok}
-        with open(t_path, 'w+') as fp_:
+        with salt.utils.fopen(t_path, 'w+') as fp_:
             fp_.write(self.serial.dumps(tdata))
         return tdata
 
@@ -129,10 +128,10 @@ class LoadAuth(object):
         t_path = os.path.join(self.opts['token_dir'], tok)
         if not os.path.isfile(t_path):
             return {}
-        with open(t_path, 'r') as fp_:
+        with salt.utils.fopen(t_path, 'r') as fp_:
             tdata = self.serial.loads(fp_.read())
         rm_tok = False
-        if not 'expire' in tdata:
+        if 'expire' not in tdata:
             # invalid token, delete it!
             rm_tok = True
         if tdata.get('expire', '0') < time.time():
@@ -148,7 +147,7 @@ class LoadAuth(object):
 
 class Resolver(object):
     '''
-    The class used to resolve options for the command line and for genric
+    The class used to resolve options for the command line and for generic
     interactive interfaces
     '''
     def __init__(self, opts):
@@ -157,7 +156,7 @@ class Resolver(object):
 
     def cli(self, eauth):
         '''
-        Execute the cli options to fill in the extra data needed for the
+        Execute the CLI options to fill in the extra data needed for the
         defined eauth system
         '''
         ret = {}
@@ -165,7 +164,7 @@ class Resolver(object):
             print('External authentication system has not been specified')
             return ret
         fstr = '{0}.auth'.format(eauth)
-        if not fstr in self.auth:
+        if fstr not in self.auth:
             print(('The specified external authentication system "{0}" is '
                    'not available').format(eauth))
             return ret
@@ -188,7 +187,7 @@ class Resolver(object):
 
     def token_cli(self, eauth, load):
         '''
-        Create the token from the cli and request the correct data to
+        Create the token from the CLI and request the correct data to
         authenticate via the passed authentication mechanism
         '''
         load['cmd'] = 'mk_token'
@@ -197,10 +196,10 @@ class Resolver(object):
                 'tcp://{0[interface]}:{0[ret_port]}'.format(self.opts),
                 )
         tdata = sreq.send('clear', load)
-        if not 'token' in tdata:
+        if 'token' not in tdata:
             return tdata
         try:
-            with open(self.opts['token_file'], 'w+') as fp_:
+            with salt.utils.fopen(self.opts['token_file'], 'w+') as fp_:
                 fp_.write(tdata['token'])
         except (IOError, OSError):
             pass
