@@ -19,7 +19,6 @@ from salt.exceptions import MinionError, SaltReqTimeoutError
 import salt.client
 import salt.crypt
 import salt.loader
-import salt.utils
 import salt.payload
 import salt.utils
 import salt.utils.templates
@@ -142,7 +141,7 @@ class Client(object):
         path = self._check_proto(path)
         # We want to make sure files start with this *directory*, use
         # '/' explicitly because the master (that's generating the
-        # list of files) only runs on posix
+        # list of files) only runs on POSIX
         if not path.endswith('/'):
             path = path + '/'
 
