@@ -317,6 +317,10 @@ def _virtual(osdata):
                 grains['virtual'] = 'kvm'
             if 'Vendor: Bochs' in output:
                 grains['virtual'] = 'kvm'
+            # Product Name: (oVirt) www.ovirt.org
+            # Red Hat Community virtualization Project based on kvm 
+            elif 'Manufacturer: oVirt' in output:
+                grains['virtual'] = 'kvm'                
             elif 'VirtualBox' in output:
                 grains['virtual'] = 'VirtualBox'
             # Product Name: VMware Virtual Platform
@@ -596,7 +600,7 @@ def os_data():
                         #     DISTRIB_RELEASE='10.10'
                         #     DISTRIB_CODENAME='squeeze'
                         #     DISTRIB_DESCRIPTION='Ubuntu 10.10'
-                        regex = re.compile('^(DISTRIB_(?:ID|RELEASE|CODENAME|DESCRIPTION))=(?:\'|")?([\w\s\.-_]+)(?:\'|")?')
+                        regex = re.compile('^(DISTRIB_(?:ID|RELEASE|CODENAME|DESCRIPTION))=(?:\'|")?([\\w\\s\\.-_]+)(?:\'|")?')
                         match = regex.match(line.rstrip('\n'))
                         if match:
                             # Adds: lsb_distrib_{id,release,codename,description}
@@ -614,7 +618,7 @@ def os_data():
                         # HOME_URL="http://archlinuxarm.org/"
                         # SUPPORT_URL="https://archlinuxarm.org/forum"
                         # BUG_REPORT_URL="https://github.com/archlinuxarm/PKGBUILDs/issues"
-                        regex = re.compile('^([\w]+)=(?:\'|")?([\w\s\.-_]+)(?:\'|")?')
+                        regex = re.compile('^([\\w]+)=(?:\'|")?([\\w\\s\\.-_]+)(?:\'|")?')
                         match = regex.match(line.rstrip('\n'))
                         if match:
                             name, value = match.groups()
@@ -668,7 +672,7 @@ def os_data():
                 else:
                     try:
                         release_re = '(Solaris|OpenIndiana(?: Development)?)' \
-                                     '\s+(\d+ \d+\/\d+|oi_\S+)?'
+                                     r'\s+(\d+ \d+\/\d+|oi_\S+)?'
                         osname, osrelease = re.search(release_re,
                                                       rel_data).groups()
                     except AttributeError:
@@ -853,7 +857,7 @@ def _dmidecode_data(regex_dict):
                 # Examples:
                 #    Product Name: 64639SU
                 #    Version: 7LETC1WW (2.21 )
-                regex = re.compile('\s+{0}\s+(.*)$'.format(item))
+                regex = re.compile(r'\s+{0}\s+(.*)$'.format(item))
                 grain = regex_dict[section][item]
                 # Skip to the next iteration if this grain
                 # has been found in the dmidecode output.
