@@ -39,7 +39,7 @@ log = logging.getLogger(__name__)
 
 def __virtual__():
     '''
-    Only work on posix-like systems
+    Only work on POSIX-like systems
     '''
     # win_file takes care of windows
     if salt.utils.is_windows():
@@ -340,7 +340,7 @@ def check_hash(path, hash):
 def find(path, **kwargs):
     '''
     Approximate the Unix find(1) command and return a list of paths that
-    meet the specified critera.
+    meet the specified criteria.
 
     The options include match criteria::
 
@@ -424,9 +424,9 @@ def find(path, **kwargs):
 
     CLI Examples::
 
-        salt '*' file.find / type=f name=\*.bak size=+10m
+        salt '*' file.find / type=f name=\\*.bak size=+10m
         salt '*' file.find /var mtime=+30d size=+10m print=path,size,mtime
-        salt '*' file.find /var/log name=\*.[0-9] mtime=+30d size=+10m delete
+        salt '*' file.find /var/log name=\\*.[0-9] mtime=+30d size=+10m delete
     '''
     try:
         finder = salt.utils.find.Finder(kwargs)
@@ -443,7 +443,7 @@ def _sed_esc(string, escape_all=False):
     Escape single quotes and forward slashes
     '''
     special_chars = "^.[$()|*+?{"
-    string = string.replace("'", "'\"'\"'").replace("/", "\/")
+    string = string.replace("'", "'\"'\"'").replace("/", "\\/")
     if escape_all is True:
         for char in special_chars:
             string = string.replace(char, "\\" + char)
@@ -573,10 +573,10 @@ def psed(path, before, after, limit='', backup='.bak', flags='gMS',
         Flags to modify the search. Valid values are :
             ``g``: Replace all occurrences of the pattern, not just the first.
             ``I``: Ignore case.
-            ``L``: Make \w, \W, \b, \B, \s and \S dependent on the locale.
+            ``L``: Make \\w, \\W, \b, \\B, \\s and \\S dependent on the locale.
             ``M``: Treat multiple lines as a single line.
             ``S``: Make `.` match all characters, including newlines.
-            ``U``: Make \w, \W, \b, \B, \d, \D, \s and \S dependent on Unicode.
+            ``U``: Make \\w, \\W, \\b, \\B, \\d, \\D, \\s and \\S dependent on Unicode.
             ``X``: Verbose (whitespace is ignored).
     multi: ``False``
         If True, treat the entire file as a single line
@@ -616,6 +616,14 @@ def psed(path, before, after, limit='', backup='.bak', flags='gMS',
     ofile.close()
 
 
+RE_FLAG_TABLE = {'I': re.I,
+                 'L': re.L,
+                 'M': re.M,
+                 'S': re.S,
+                 'U': re.U,
+                 'X': re.X}
+
+
 def _psed(text, before, after, limit, flags):
     '''
     Does the actual work for file.psed, so that single lines can be passed in
@@ -632,14 +640,8 @@ def _psed(text, before, after, limit, flags):
         flags = flags.replace('g', '')
 
     aflags = 0
-    flag_table = {'I': 2,
-                  'L': 4,
-                  'M': 8,
-                  'S': 16,
-                  'U': 32,
-                  'X': 64}
     for flag in flags:
-        aflags += flag_table[flag]
+        aflags |= RE_FLAG_TABLE[flag]
 
     before = re.compile(before, flags=aflags)
     text = re.sub(before, after, atext, count=count)
@@ -1398,7 +1400,7 @@ def check_file_meta(
         # Write a tempfile with the static contents
         tmp = salt.utils.mkstemp(text=True)
         with salt.utils.fopen(tmp, 'w') as tmp_:
-            tmp_.write(contents)
+            tmp_.write(str(contents))
         # Compare the static contents with the named file
         with contextlib.nested(
                 salt.utils.fopen(tmp, 'rb'),
@@ -1432,7 +1434,7 @@ def get_diff(
 
     CLI Example::
 
-        salt \* file.get_diff /home/fred/.vimrc salt://users/fred/.vimrc
+        salt '*' file.get_diff /home/fred/.vimrc salt://users/fred/.vimrc
     '''
     ret = ''
 
@@ -1543,7 +1545,7 @@ def manage_file(name,
             # Write the static contents to a temporary file
             tmp = salt.utils.mkstemp(text=True)
             with salt.utils.fopen(tmp, 'w') as tmp_:
-                tmp_.write(contents)
+                tmp_.write(str(contents))
 
             # Compare contents of files to know if we need to replace
             with contextlib.nested(
@@ -1654,7 +1656,7 @@ def manage_file(name,
             # Write the static contents to a temporary file
             tmp = salt.utils.mkstemp(text=True)
             with salt.utils.fopen(tmp, 'w') as tmp_:
-                tmp_.write(contents)
+                tmp_.write(str(contents))
             # Copy into place
             salt.utils.copyfile(
                     tmp,
