@@ -4,9 +4,9 @@ Package support for FreeBSD
 
 # Import python libs
 import logging
-
-# Import python libs
 import os
+
+# Import salt libs
 import salt.utils
 
 
@@ -149,7 +149,7 @@ def list_pkgs(versions_as_list=False):
 
         salt '*' pkg.list_pkgs
     '''
-    versions_as_list = __salt__['config.is_true'](versions_as_list)
+    versions_as_list = salt.utils.is_true(versions_as_list)
     if _check_pkgng():
         pkg_command = '{0} info'.format(_cmd('pkg'))
     else:
@@ -403,8 +403,8 @@ def file_list(*packages):
     '''
     ret = file_dict(*packages)
     files = []
-    for pkg, its_files in ret['files'].items():
-        files.extend(its_files)
+    for pkg_files in ret['files'].values():
+        files.extend(pkg_files)
     ret['files'] = files
     return ret
 
