@@ -36,7 +36,7 @@ def _add_var(var, value):
     if __salt__['file.contains'](makeconf, layman):
         # TODO perhaps make this a function in the file module?
         cmd = r"sed -i '/{0}/ i\{1}' {2}".format(
-            layman.replace("/", "\/"),
+            layman.replace("/", "\\/"),
             fullvar,
             makeconf)
         print cmd
@@ -195,7 +195,7 @@ def set_cflags(value):
 
     CLI Example::
 
-        salt '*' makeconf.set_cflags '\-march=native \-O2 \-pipe'
+        salt '*' makeconf.set_cflags '\\-march=native \\-O2 \\-pipe'
     '''
     return set_var('CFLAGS', value)
 
@@ -223,7 +223,7 @@ def append_cflags(value):
 
     CLI Example::
 
-        salt '*' makeconf.append_cflags '\-pipe'
+        salt '*' makeconf.append_cflags '\\-pipe'
     '''
     return append_var('CFLAGS', value)
 
@@ -238,7 +238,7 @@ def trim_cflags(value):
 
     CLI Example::
 
-        salt '*' makeconf.trim_cflags '\-pipe'
+        salt '*' makeconf.trim_cflags '\\-pipe'
     '''
     return trim_var('CFLAGS', value)
 
@@ -250,7 +250,7 @@ def cflags_contains(value):
 
     CLI Example::
 
-        salt '*' makeconf.cflags_contains '\-pipe'
+        salt '*' makeconf.cflags_contains '\\-pipe'
     '''
     return var_contains('CFLAGS', value)
 
@@ -265,7 +265,7 @@ def set_cxxflags(value):
 
     CLI Example::
 
-        salt '*' makeconf.set_cxxflags '\-march=native \-O2 \-pipe'
+        salt '*' makeconf.set_cxxflags '\\-march=native \\-O2 \\-pipe'
     '''
     return set_var('CXXFLAGS', value)
 
@@ -293,7 +293,7 @@ def append_cxxflags(value):
 
     CLI Example::
 
-        salt '*' makeconf.append_cxxflags '\-pipe'
+        salt '*' makeconf.append_cxxflags '\\-pipe'
     '''
     return append_var('CXXFLAGS', value)
 
@@ -308,7 +308,7 @@ def trim_cxxflags(value):
 
     CLI Example::
 
-        salt '*' makeconf.trim_cxxflags '\-pipe'
+        salt '*' makeconf.trim_cxxflags '\\-pipe'
     '''
     return trim_var('CXXFLAGS', value)
 
@@ -320,7 +320,7 @@ def cxxflags_contains(value):
 
     CLI Example::
 
-        salt '*' makeconf.cxxflags_contains '\-pipe'
+        salt '*' makeconf.cxxflags_contains '\\-pipe'
     '''
     return var_contains('CXXFLAGS', value)
 
@@ -375,7 +375,7 @@ def set_makeopts(value):
 
     CLI Example::
 
-        salt '*' makeconf.set_makeopts '\-j3'
+        salt '*' makeconf.set_makeopts '\\-j3'
     '''
     return set_var('MAKEOPTS', value)
 
@@ -403,7 +403,7 @@ def append_makeopts(value):
 
     CLI Example::
 
-        salt '*' makeconf.append_makeopts '\-j3'
+        salt '*' makeconf.append_makeopts '\\-j3'
     '''
     return append_var('MAKEOPTS', value)
 
@@ -418,7 +418,7 @@ def trim_makeopts(value):
 
     CLI Example::
 
-        salt '*' makeconf.trim_makeopts '\-j3'
+        salt '*' makeconf.trim_makeopts '\\-j3'
     '''
     return trim_var('MAKEOPTS', value)
 
@@ -430,7 +430,7 @@ def makeopts_contains(value):
 
     CLI Example::
 
-        salt '*' makeconf.makeopts_contains '\-j3'
+        salt '*' makeconf.makeopts_contains '\\-j3'
     '''
     return var_contains('MAKEOPTS', value)
 
@@ -445,7 +445,7 @@ def set_emerge_default_opts(value):
 
     CLI Example::
 
-        salt '*' makeconf.set_emerge_default_opts '\-\-jobs'
+        salt '*' makeconf.set_emerge_default_opts '\\-\\-jobs'
     '''
     return set_var('EMERGE_DEFAULT_OPTS', value)
 
@@ -473,7 +473,7 @@ def append_emerge_default_opts(value):
 
     CLI Example::
 
-        salt '*' makeconf.append_emerge_default_opts '\-\-jobs'
+        salt '*' makeconf.append_emerge_default_opts '\\-\\-jobs'
     '''
     return append_var('EMERGE_DEFAULT_OPTS', value)
 
@@ -488,7 +488,7 @@ def trim_emerge_default_opts(value):
 
     CLI Example::
 
-        salt '*' makeconf.trim_emerge_default_opts '\-\-jobs'
+        salt '*' makeconf.trim_emerge_default_opts '\\-\\-jobs'
     '''
     return trim_var('EMERGE_DEFAULT_OPTS', value)
 
@@ -500,7 +500,7 @@ def emerge_default_opts_contains(value):
 
     CLI Example::
 
-        salt '*' makeconf.emerge_default_opts_contains '\-\-jobs'
+        salt '*' makeconf.emerge_default_opts_contains '\\-\\-jobs'
     '''
     return var_contains('EMERGE_DEFAULT_OPTS', value)
 
