@@ -34,24 +34,40 @@ def version():
     ret = out[0].split(': ')
     return ret[-1]
 
+def configtest():
+    '''
+    test configuration and exit
+
+    CLI Example::
+       
+        salt '*' nginx.configtest
+    '''
+
+    cmd = '{0} -t'.format(__detect_os())
+    out = __salt__['cmd.run'](cmd).splitlines()
+    ret = out[0].split(': ')
+    return ret[-1]
+
+    
+
 def signal(signal=None):
     '''
-    Signals nginx to start, restart, or stop.
+    Signals nginx to start, reload, reopen or stop.
 
     CLI Example::
 
         salt '*' nginx.signal reload
     '''
-    valid_signals = ('reopen', 'stop', 'quit', 'reload')
+    valid_signals = ('start', 'reopen', 'stop', 'quit', 'reload')
 
     if signal not in valid_signals:
         return
 
     # Make sure you use the right arguments
-    if signal in valid_signals:
-        arguments = ' -s {0}'.format(signal)
+    if signal == "start":
+        arguments = ''
     else:
-        arguments = ' {0}'.format(signal)
+        arguments = ' -s {0}'.format(signal)
     cmd = __detect_os() + arguments
     out = __salt__['cmd.run_all'](cmd)
 
