@@ -9,8 +9,10 @@ Module to provide Postgres compatibility to salt.
         postgres.port: '5432'
         postgres.user: 'postgres'
         postgres.pass: ''
-        postgres.db: 'postgres'
+        postgres.maintenance_db: 'postgres'
 
+    The default for the maintenance_db is 'postgres' and in most cases it can
+    be left at the default setting.
     This data can also be passed into pillar. Options passed into opts will
     overwrite options passed into pillar
 '''
@@ -19,10 +21,13 @@ Module to provide Postgres compatibility to salt.
 import datetime
 import pipes
 import logging
+import csv
+import StringIO
+import os
+import tempfile
 
 # Import salt libs
 import salt.utils
-from salt.exceptions import CommandNotFoundError
 
 log = logging.getLogger(__name__)
 
@@ -36,41 +41,48 @@ def __virtual__():
     return False
 
 
-def _get_runas(runas=None):
-    '''
-    Returns the default runas user for this platform
-    '''
-    if runas is not None:
-        return runas
-
-    if 'FreeBSD' in __grains__['os_family']:
-        return 'pgsql'
-    else:
-        return 'postgres'
-
-
-def _run_psql(cmd, runas=None, password=None, run_cmd="cmd.run_all"):
+def _run_psql(cmd, runas=None, password=None, host=None,
+              run_cmd="cmd.run_all"):
     '''
     Helper function to call psql, because the password requirement
     makes this too much code to be repeated in each function below
     '''
-    kwargs = {"runas": _get_runas(runas)}
+    kwargs = {}
+    if runas is None:
+        if not host:
+            host = __salt__['config.option']('postgres.host')
+        if not host or host.startswith('/'):
+            if 'FreeBSD' in __grains__['os_family']:
+                runas = 'pgsql'
+            else:
+                runas = 'postgres'
 
-    if not password:
+    if runas:
+        kwargs['runas'] = runas
+
+    if password is None:
         password = __salt__['config.option']('postgres.pass')
-    if password:
-        kwargs["env"] = {"PGPASSWORD": password}
-        # PGPASSWORD has been deprecated, supposedly leading to
-        # protests. Currently, this seems the simplest way to solve
-        # this. If needed in the future, a tempfile could also be
-        # written and the filename set to the PGPASSFILE variable. see
-        # http://www.postgresql.org/docs/8.4/static/libpq-pgpass.html
+    if password is not None:
+        pgpassfile = salt.utils.mkstemp(text=True)
+        with salt.utils.fopen(pgpassfile, 'w') as fp_:
+            fp_.write('{0}:*:*:{1}:{2}'.format(
+                'localhost' if not host or host.startswith('/') else host,
+                runas if runas else '*',
+                password
+            ))
+            __salt__['file.chown'](pgpassfile, runas, '')
+            kwargs['env'] = {'PGPASSFILE': pgpassfile}
 
-    return __salt__[run_cmd](cmd, **kwargs)
+    ret = __salt__[run_cmd](cmd, **kwargs)
+
+    if password is not None and not __salt__['file.remove'](pgpassfile):
+        log.warning('Remove PGPASSFILE failed')
+
+    return ret
 
 
-def version(user=None, host=None, port=None, db=None, password=None,
-            runas=None):
+def version(user=None, host=None, port=None, maintenance_db=None,
+            password=None, runas=None):
     '''
     Return the version of a Postgres server.
 
@@ -80,15 +92,16 @@ def version(user=None, host=None, port=None, db=None, password=None,
     '''
     query = 'SELECT setting FROM pg_catalog.pg_settings ' \
             'WHERE name = \'server_version\''
-    cmd = _psql_cmd('-c', query, '-t',
-                    host=host, user=user, port=port, db=db, password=password)
-    ret = _run_psql(cmd, runas=runas, password=password)
+    cmd = _psql_cmd('-c', query, '-t', host=host, user=user,
+                    port=port, maintenance_db=maintenance_db,
+                    password=password)
+    ret = _run_psql(cmd, runas=runas, password=password, host=host)
 
     for line in ret['stdout'].splitlines():
         return line
 
 
-def _connection_defaults(user=None, host=None, port=None, db=None,
+def _connection_defaults(user=None, host=None, port=None, maintenance_db=None,
                          password=None):
     '''
     Returns a tuple of (user, host, port, db) with config, pillar, or default
@@ -100,12 +113,12 @@ def _connection_defaults(user=None, host=None, port=None, db=None,
         host = __salt__['config.option']('postgres.host')
     if not port:
         port = __salt__['config.option']('postgres.port')
-    if not db:
-        db = __salt__['config.option']('postgres.db')
-    if not password:
+    if not maintenance_db:
+        maintenance_db = __salt__['config.option']('postgres.maintenance_db')
+    if password is None:
         password = __salt__['config.option']('postgres.pass')
 
-    return (user, host, port, db, password)
+    return (user, host, port, maintenance_db, password)
 
 
 def _psql_cmd(*args, **kwargs):
@@ -115,17 +128,17 @@ def _psql_cmd(*args, **kwargs):
     Accept optional keyword arguments: user, host and port as well as any
     number or positional arguments to be added to the end of command.
     '''
-    (user, host, port, db, password) = _connection_defaults(
+    (user, host, port, maintenance_db, password) = _connection_defaults(
         kwargs.get('user'),
         kwargs.get('host'),
         kwargs.get('port'),
-        kwargs.get('db'),
+        kwargs.get('maintenance_db'),
         kwargs.get('password'))
 
     cmd = [salt.utils.which('psql'),
            '--no-align',
            '--no-readline']
-    if not password:
+    if password is None:
         cmd += ['--no-password']
     if user:
         cmd += ['--username', user]
@@ -133,16 +146,58 @@ def _psql_cmd(*args, **kwargs):
         cmd += ['--host', host]
     if port:
         cmd += ['--port', port]
-    if db:
-        cmd += ['--dbname', db]
+    if not maintenance_db:
+        maintenance_db = 'postgres'
+    cmd += ['--dbname', maintenance_db]
     cmd += args
     cmdstr = ' '.join(map(pipes.quote, cmd))
     return cmdstr
 
 
+def psql_query(query, user=None, host=None, port=None, maintenance_db=None,
+               password=None, runas=None):
+    '''
+    Run an SQL-Query and return the results as a list. This command
+    only supports SELECT statements.
+
+    CLI Example::
+
+        salt '*' postgres.psql_query 'select * from pg_stat_activity'
+    '''
+    ret = []
+
+    csv_query = 'COPY ({0}) TO STDOUT WITH CSV HEADER'.format(
+        query.strip().rstrip(';'))
+
+    cmd = _psql_cmd(
+        # always use the same datestyle settings to allow parsing dates
+        # regardless what server settings are configured
+        '-v', 'datestyle=ISO,MDY',
+        '-c', csv_query,
+        host=host, user=user, port=port, maintenance_db=maintenance_db,
+        password=password)
+
+    cmdret = _run_psql(cmd, runas=runas, password=password)
+
+    if cmdret['retcode'] > 0:
+        return ret
+
+    csv_file = StringIO.StringIO(cmdret['stdout'])
+    header = {}
+    for row in csv.reader(csv_file, delimiter=',', quotechar='"'):
+        if not row:
+            continue
+        if not header:
+            header = row
+            continue
+        ret.append(dict(zip(header, row)))
+
+    return ret
+
+
 # Database related actions
 
-def db_list(user=None, host=None, port=None, db=None,
+def db_list(user=None, host=None, port=None, maintenance_db=None,
             password=None, runas=None):
     '''
     Return dictionary with information about databases of a Postgres server.
@@ -153,39 +208,27 @@ def db_list(user=None, host=None, port=None, db=None,
     '''
 
     ret = {}
-    header = ['Name',
-              'Owner',
-              'Encoding',
-              'Collate',
-              'Ctype',
-              'Access privileges']
 
     query = 'SELECT datname as "Name", pga.rolname as "Owner", ' \
             'pg_encoding_to_char(encoding) as "Encoding", ' \
             'datcollate as "Collate", datctype as "Ctype", ' \
-            'datacl as "Access privileges" FROM pg_database pgd, ' \
-            'pg_roles pga WHERE pga.oid = pgd.datdba'
+            'datacl as "Access privileges", spcname as "Tablespace" ' \
+            'FROM pg_database pgd, pg_roles pga, pg_tablespace pgts ' \
+            'WHERE pga.oid = pgd.datdba AND pgts.oid = pgd.dattablespace'
 
-    cmd = _psql_cmd('-c', query, '-t',
-                    host=host, user=user, port=port, db=db, password=password)
+    rows = psql_query(query, runas=runas, host=host, user=user,
+                      port=port, maintenance_db=maintenance_db,
+                      password=password)
 
-    cmdret = _run_psql(cmd, runas=runas, password=password)
-
-    if cmdret['retcode'] > 0:
-        return ret
-
-    for line in cmdret['stdout'].splitlines():
-        if line.count('|') != 5:
-            log.warning('Unexpected string: {0}'.format(line))
-            continue
-        comps = line.split('|')
-        ret[comps[0]] = dict(zip(header[1:], comps[1:]))
+    for row in rows:
+        ret[row['Name']] = row
+        ret[row['Name']].pop('Name')
 
     return ret
 
 
-def db_exists(name, user=None, host=None, port=None, db=None, password=None,
-              runas=None):
+def db_exists(name, user=None, host=None, port=None, maintenance_db=None,
+              password=None, runas=None):
     '''
     Checks if a database exists on the Postgres server.
 
@@ -194,7 +237,8 @@ def db_exists(name, user=None, host=None, port=None, db=None, password=None,
         salt '*' postgres.db_exists 'dbname'
     '''
 
-    databases = db_list(user=user, host=host, port=port, db=db,
+    databases = db_list(user=user, host=host, port=port,
+                        maintenance_db=maintenance_db,
                         password=password, runas=runas)
     return name in databases
 
@@ -203,11 +247,10 @@ def db_create(name,
               user=None,
               host=None,
               port=None,
-              db=None,
+              maintenance_db=None,
               password=None,
               tablespace=None,
               encoding=None,
-              locale=None,
               lc_collate=None,
               lc_ctype=None,
               owner=None,
@@ -248,14 +291,46 @@ def db_create(name,
         query += ' '.join(with_chunks)
 
     # Execute the command
-    cmd = _psql_cmd('-c', query, user=user, host=host, port=port, db=db,
+    cmd = _psql_cmd('-c', query, user=user, host=host, port=port,
+                    maintenance_db=maintenance_db,
                     password=password)
-    ret = _run_psql(cmd, runas=runas, password=password)
+    ret = _run_psql(cmd, runas=runas, password=password, host=host)
 
     return ret['retcode'] == 0
 
 
-def db_remove(name, user=None, host=None, port=None, db=None,
+def db_alter(name, user=None, host=None, port=None, maintenance_db=None,
+             password=None, tablespace=None, owner=None, runas=None):
+    '''
+    Change tablesbase or/and owner of databse.
+
+    CLI Example::
+
+        salt '*' postgres.db_alter dbname owner=otheruser
+    '''
+    if not any((tablespace, owner)):
+        return True  # Nothing todo?
+
+    queries = []
+    if owner:
+        queries.append('ALTER DATABASE "{0}" OWNER TO "{1}"'.format(
+            name, owner
+        ))
+    if tablespace:
+        queries.append('ALTER DATABASE "{0}" SET TABLESPACE "{1}"'.format(
+            name, tablespace
+        ))
+    for Q in queries:
+        cmd = _psql_cmd('-c', Q, user=user, host=host, port=port,
+                        maintenance_db=maintenance_db, password=password)
+        ret = _run_psql(cmd, runas=runas, password=password, host=host)
+        if ret['retcode'] != 0:
+            return False
+
+    return True
+
+
+def db_remove(name, user=None, host=None, port=None, maintenance_db=None,
               password=None, runas=None):
     '''
     Removes a databases from the Postgres server.
@@ -265,17 +340,17 @@ def db_remove(name, user=None, host=None, port=None, db=None,
         salt '*' postgres.db_remove 'dbname'
     '''
 
-    # db doesnt exist, proceed
+    # db doesn't exist, proceed
     query = 'DROP DATABASE {0}'.format(name)
-    cmd = _psql_cmd('-c', query, user=user, host=host, port=port, db=db,
-                    password=password)
-    ret = _run_psql(cmd, runas=runas, password=password)
+    cmd = _psql_cmd('-c', query, user=user, host=host, port=port,
+                    maintenance_db=maintenance_db, password=password)
+    ret = _run_psql(cmd, runas=runas, password=password, host=host)
     return ret['retcode'] == 0
 
 
 # User related actions
 
-def user_list(user=None, host=None, port=None, db=None,
+def user_list(user=None, host=None, port=None, maintenance_db=None,
               password=None, runas=None):
     '''
     Return a dict with information about users of a Postgres server.
@@ -286,71 +361,71 @@ def user_list(user=None, host=None, port=None, db=None,
     '''
 
     ret = {}
-    header = ['name',
-              'superuser',
-              'inherits privileges',
-              'can create roles',
-              'can create databases',
-              'can update system catalogs',
-              'can login',
-              'replication',
-              'connections',
-              'expiry time',
-              'defaults variables']
 
     ver = version(user=user,
                   host=host,
                   port=port,
-                  db=db,
+                  maintenance_db=maintenance_db,
                   password=password,
                   runas=runas).split('.')
     if len(ver) >= 2 and int(ver[0]) >= 9 and int(ver[1]) >= 1:
         query = (
-            'SELECT rolname, rolsuper, rolinherit, rolcreaterole, '
-            'rolcreatedb, rolcatupdate, rolcanlogin, rolreplication, '
-            'rolconnlimit, rolvaliduntil::timestamp(0), rolconfig '
+            'SELECT rolname as "name", rolsuper as "superuser", '
+            'rolinherit as "inherits privileges", '
+            'rolcreaterole as "can create roles", '
+            'rolcreatedb as "can create databases", '
+            'rolcatupdate as "can update system catalogs", '
+            'rolcanlogin as "can login", rolreplication as "replication", '
+            'rolconnlimit as "connections", '
+            'rolvaliduntil::timestamp(0) as "expiry time", '
+            'rolconfig  as "defaults variables" '
             'FROM pg_roles'
         )
     else:
         query = (
-            'SELECT rolname, rolsuper, rolinherit, rolcreaterole, '
-            'rolcreatedb, rolcatupdate, rolcanlogin, NULL, '
-            'rolconnlimit, rolvaliduntil::timestamp(0), rolconfig '
+            'SELECT rolname as "name", rolsuper as "superuser", '
+            'rolinherit as "inherits privileges", '
+            'rolcreaterole as "can create roles", '
+            'rolcreatedb as "can create databases", '
+            'rolcatupdate as "can update system catalogs", '
+            'rolcanlogin as "can login", NULL as "replication", '
+            'rolconnlimit as "connections", '
+            'rolvaliduntil::timestamp(0) as "expiry time", '
+            'rolconfig  as "defaults variables" '
             'FROM pg_roles'
         )
-    cmd = _psql_cmd('-c', query, '-t',
-                    host=host, user=user, port=port, db=db, password=password)
 
-    cmdret = _run_psql(cmd, runas=runas, password=password)
+    rows = psql_query(query, runas=runas, host=host, user=user,
+                      port=port, maintenance_db=maintenance_db,
+                      password=password)
 
-    if cmdret['retcode'] > 0:
-        return ret
-
-    for line in cmdret['stdout'].splitlines():
-        comps = line.split('|')
-        # type casting
-        for i in range(1, 8):
-            if comps[i] == 't':
-                comps[i] = True
-            elif comps[i] == 'f':
-                comps[i] = False
-            else:
-                comps[i] = None
-        comps[8] = int(comps[8])
-        if comps[9]:
-            comps[9] = datetime.datetime.strptime(
-                comps[9], '%Y-%m-%d %H:%M:%S'
-            )
+    def get_bool(rowdict, key):
+        if rowdict[key] == 't':
+            return True
+        elif rowdict[key] == 'f':
+            return False
         else:
-            comps[9] = None
-        if not comps[10]:
-            comps[10] = None
-        ret[comps[0]] = dict(zip(header[1:], comps[1:]))
+            return None
+
+    for row in rows:
+        retrow = {}
+        for key in ('superuser', 'inherits privileges', 'can create roles',
+                    'can create databases', 'can update system catalogs',
+                    'can login', 'replication', 'connections'):
+            retrow[key] = get_bool(row, key)
+        for date_key in ('expiry time',):
+            try:
+                retrow[date_key] = datetime.datetime.strptime(
+                    row['date_key'], '%Y-%m-%d %H:%M:%S')
+            except (ValueError, KeyError):
+                retrow[date_key] = None
+        retrow['defaults variables'] = row['defaults variables']
+        ret[row['name']] = retrow
 
     return ret
 
 
-def user_exists(name, user=None, host=None, port=None, db=None,
+def user_exists(name, user=None, host=None, port=None, maintenance_db=None,
                 password=None, runas=None):
     '''
     Checks if a user exists on the Postgres server.
@@ -363,7 +438,7 @@ def user_exists(name, user=None, host=None, port=None, db=None,
     return name in user_list(user=user,
                              host=host,
                              port=port,
-                             db=db,
+                             maintenance_db=maintenance_db,
                              password=password,
                              runas=runas)
 
@@ -373,7 +448,7 @@ def _role_create(name,
                  user=None,
                  host=None,
                  port=None,
-                 db=None,
+                 maintenance_db=None,
                  password=None,
                  createdb=False,
                  createuser=False,
@@ -394,12 +469,13 @@ def _role_create(name,
         create_type = 'ROLE'
 
     # check if role exists
-    if user_exists(name, user, host, port, db, password=password, runas=runas):
+    if user_exists(name, user, host, port, maintenance_db,
+                   password=password, runas=runas):
         log.info('{0} \'{1}\' already exists'.format(create_type, name,))
         return False
 
     sub_cmd = 'CREATE {0} "{1}" WITH'.format(create_type, name, )
-    if rolepassword:
+    if rolepassword is not None:
         if encrypted:
             sub_cmd = '{0} ENCRYPTED'.format(sub_cmd, )
         escaped_password = rolepassword.replace('\'', '\'\'')
@@ -418,16 +494,17 @@ def _role_create(name,
     if sub_cmd.endswith('WITH'):
         sub_cmd = sub_cmd.replace(' WITH', '')
 
-    cmd = _psql_cmd('-c', sub_cmd, host=host, user=user, port=port, db=db,
-                    password=password)
-    return _run_psql(cmd, runas=runas, password=password, run_cmd="cmd.run")
+    cmd = _psql_cmd('-c', sub_cmd, host=host, user=user, port=port,
+                    maintenance_db=maintenance_db, password=password)
+    return _run_psql(cmd, runas=runas, password=password, host=host,
+                     run_cmd="cmd.run")
 
 
 def user_create(username,
                 user=None,
                 host=None,
                 port=None,
-                db=None,
+                maintenance_db=None,
                 password=None,
                 createdb=False,
                 createuser=False,
@@ -449,7 +526,7 @@ def user_create(username,
                         user,
                         host,
                         port,
-                        db,
+                        maintenance_db,
                         password,
                         createdb,
                         createuser,
@@ -465,7 +542,7 @@ def _role_update(name,
                  user=None,
                  host=None,
                  port=None,
-                 db=None,
+                 maintenance_db=None,
                  password=None,
                  createdb=False,
                  createuser=False,
@@ -479,12 +556,13 @@ def _role_update(name,
     '''
 
     # check if user exists
-    if not user_exists(name, user, host, port, db, password, runas=runas):
+    if not user_exists(name, user, host, port, maintenance_db, password,
+                       runas=runas):
         log.info('User \'{0}\' does not exist'.format(name,))
         return False
 
     sub_cmd = 'ALTER ROLE {0} WITH'.format(name, )
-    if rolepassword:
+    if rolepassword is not None:
         sub_cmd = '{0} PASSWORD \'{1}\''.format(sub_cmd, rolepassword)
     if createdb:
         sub_cmd = '{0} CREATEDB'.format(sub_cmd, )
@@ -502,16 +580,17 @@ def _role_update(name,
         for group in groups.split(','):
             sub_cmd = '{0}; GRANT {1} TO {2}'.format(sub_cmd, group, name)
 
-    cmd = _psql_cmd('-c', sub_cmd, host=host, user=user, port=port, db=db,
-                    password=password)
-    return _run_psql(cmd, runas=runas, password=password, run_cmd="cmd.run")
+    cmd = _psql_cmd('-c', sub_cmd, host=host, user=user, port=port,
+                    maintenance_db=maintenance_db, password=password)
+    return _run_psql(cmd, runas=runas, password=password, host=host,
+                     run_cmd="cmd.run")
 
 
 def user_update(username,
                 user=None,
                 host=None,
                 port=None,
-                db=None,
+                maintenance_db=None,
                 password=None,
                 createdb=False,
                 createuser=False,
@@ -531,7 +610,7 @@ def user_update(username,
                         user,
                         host,
                         port,
-                        db,
+                        maintenance_db,
                         password,
                         createdb,
                         createuser,
@@ -542,24 +621,26 @@ def user_update(username,
                         runas)
 
 
-def _role_remove(name, user=None, host=None, port=None, db=None,
+def _role_remove(name, user=None, host=None, port=None, maintenance_db=None,
                  password=None, runas=None):
     '''
     Removes a role from the Postgres Server
     '''
 
     # check if user exists
-    if not user_exists(name, user, host, port, db, password=password,
-                       runas=runas):
+    if not user_exists(name, user, host, port, maintenance_db,
+                       password=password, runas=runas):
         log.info('User \'{0}\' does not exist'.format(name,))
         return False
 
     # user exists, proceed
     sub_cmd = 'DROP ROLE {0}'.format(name)
-    cmd = _psql_cmd('-c', sub_cmd, host=host, user=user, port=port, db=db,
-                    password=password)
-    _run_psql(cmd, runas=runas, password=password, run_cmd="cmd.run")
-    if not user_exists(name, user, host, port, db, password=password, runas=runas):
+    cmd = _psql_cmd('-c', sub_cmd, host=host, user=user, port=port,
+                    maintenance_db=maintenance_db, password=password)
+    _run_psql(cmd, runas=runas, password=password, host=host,
+              run_cmd="cmd.run")
+    if not user_exists(name, user, host, port, maintenance_db,
+                       password=password, runas=runas):
         return True
     else:
         log.info('Failed to delete user \'{0}\'.'.format(name, ))
@@ -569,7 +650,7 @@ def user_remove(username,
                 user=None,
                 host=None,
                 port=None,
-                db=None,
+                maintenance_db=None,
                 password=None,
                 runas=None):
     '''
@@ -579,7 +660,8 @@ def user_remove(username,
 
         salt '*' postgres.user_remove 'username'
     '''
-    return _role_remove(username, user, host, port, db, password, runas)
+    return _role_remove(username, user, host, port, maintenance_db,
+                        password, runas)
 
 
 # Group related actions
@@ -588,7 +670,7 @@ def group_create(groupname,
                  user=None,
                  host=None,
                  port=None,
-                 db=None,
+                 maintenance_db=None,
                  password=None,
                  createdb=False,
                  createuser=False,
@@ -611,7 +693,7 @@ def group_create(groupname,
                         user,
                         host,
                         port,
-                        db,
+                        maintenance_db,
                         password,
                         createdb,
                         createuser,
@@ -627,7 +709,7 @@ def group_update(groupname,
                  user=None,
                  host=None,
                  port=None,
-                 db=None,
+                 maintenance_db=None,
                  password=None,
                  createdb=False,
                  createuser=False,
@@ -647,7 +729,7 @@ def group_update(groupname,
                         user,
                         host,
                         port,
-                        db,
+                        maintenance_db,
                         password,
                         createdb,
                         createuser,
@@ -662,7 +744,7 @@ def group_remove(groupname,
                  user=None,
                  host=None,
                  port=None,
-                 db=None,
+                 maintenance_db=None,
                  password=None,
                  runas=None):
     '''
@@ -672,4 +754,75 @@ def group_remove(groupname,
 
         salt '*' postgres.group_remove 'groupname'
     '''
-    return _role_remove(groupname, user, host, port, db, password, runas)
+    return _role_remove(groupname, user, host, port, maintenance_db,
+                        password, runas)
+
+def owner_to(dbname,
+                ownername,
+                user=None,
+                host=None,
+                port=None,
+                password=None,
+                runas=None):
+    '''
+    Set the owner of all schemas, functions, tables, views and sequences to
+    the given username.
+
+    CLI Example::
+
+        salt '*' postgres.owner_to 'dbname' 'username'
+    '''
+
+    sqlfile = tempfile.NamedTemporaryFile()
+    sqlfile.write('begin;\n')
+    sqlfile.write('alter database {0} owner to {1};\n'.format(dbname, ownername))
+
+    queries = (
+        #schemas
+        ( 
+         'alter schema %(n)s owner to %(owner)s;',
+         'select quote_ident(schema_name) as n from information_schema.schemata;'
+         ),
+        # tables and views
+        (
+         'alter table %(n)s owner to %(owner)s;',
+         "select quote_ident(table_schema)||'.'||quote_ident(table_name) as n " +
+            "from information_schema.tables where table_schema not in ('pg_catalog', 'information_schema');"
+         ),
+        # functions
+        (
+         'alter function %(n)s owner to %(owner)s;',
+         "select p.oid::regprocedure::text as n from pg_catalog.pg_proc p " +
+            "join pg_catalog.pg_namespace ns on p.pronamespace=ns.oid where ns.nspname not in ('pg_catalog', 'information_schema') " +
+            " and not p.proisagg;"
+         ),
+        # aggregate functions
+        (
+         'alter aggregate %(n)s owner to %(owner)s;',
+         "select p.oid::regprocedure::text as n from pg_catalog.pg_proc p " +
+            "join pg_catalog.pg_namespace ns on p.pronamespace=ns.oid where ns.nspname not in ('pg_catalog', 'information_schema') " +
+            " and p.proisagg;"
+         ),
+        # sequences
+        (
+         'alter sequence %(n)s owner to %(owner)s;',
+         "select quote_ident(sequence_schema)||'.'||quote_ident(sequence_name) as n from information_schema.sequences;"
+        )
+    )
+
+    for fmt, query in queries:
+        ret = psql_query(query, user=user, host=host, port=port, maintenance_db=dbname,
+                   password=password, runas=runas)
+        for row in ret:
+            line = fmt % {'owner': ownername, 'n':row['n']}
+            sqlfile.write(line+"\n")
+
+    sqlfile.write('commit;\n')
+    sqlfile.flush()
+    os.chmod(sqlfile.name, 0644) # ensure psql can read the file
+
+    # run the generated sqlfile in the db
+    cmd = _psql_cmd('-f', sqlfile.name, user=user, host=host, port=port, \
+                password=password, maintenance_db=dbname)
+    cmdret = _run_psql(cmd, runas=runas, password=password)
+    return cmdret
