@@ -6,16 +6,18 @@ from __future__ import absolute_import
 # Import python libs
 try:
     import sqlite3
-    has_sqlite3 = True
+    HAS_SQLITE3 = True
 except ImportError:
-    has_sqlite3 = False
+    HAS_SQLITE3 = False
 
 
+# pylint: disable-msg=C0103
 def __virtual__():
-    if not has_sqlite3:
+    if not HAS_SQLITE3:
         return False
     return 'sqlite3'
 
+
 def _connect(db=None):
     if db is None:
         return False
@@ -24,6 +26,7 @@ def _connect(db=None):
     cur = con.cursor()
     return cur
 
+
 def version():
     '''
     Return version of pysqlite
@@ -34,6 +37,7 @@ def version():
     '''
     return sqlite3.version
 
+
 def sqlite_version():
     '''
     Return version of sqlite
@@ -44,6 +48,7 @@ def sqlite_version():
     '''
     return sqlite3.sqlite_version
 
+
 def modify(db=None, sql=None):
     '''
     Issue an SQL query to sqlite3 (with no return data), usually used
@@ -61,6 +66,7 @@ def modify(db=None, sql=None):
     cur.execute(sql)
     return True
 
+
 def fetch(db=None, sql=None):
     '''
     Retrieve data from an sqlite3 db (returns all rows, be careful!)
@@ -78,6 +84,7 @@ def fetch(db=None, sql=None):
     rows = cur.fetchall()
     return rows
 
+
 def tables(db=None):
     '''
     Show all tables in the database
@@ -91,10 +98,13 @@ def tables(db=None):
     if not cur:
         return False
 
-    cur.execute("SELECT name FROM sqlite_master WHERE type='table' ORDER BY name;")
+    cur.execute(
+        "SELECT name FROM sqlite_master WHERE type='table' ORDER BY name;"
+    )
     rows = cur.fetchall()
     return rows
 
+
 def indices(db=None):
     '''
     Show all indices in the database
@@ -108,10 +118,13 @@ def indices(db=None):
     if not cur:
         return False
 
-    cur.execute("SELECT name FROM sqlite_master WHERE type='index' ORDER BY name;")
+    cur.execute(
+        "SELECT name FROM sqlite_master WHERE type='index' ORDER BY name;"
+    )
     rows = cur.fetchall()
     return rows
 
+
 def indexes(db=None):
     '''
     Show all indices in the database, for people with poor spelling skills
@@ -121,4 +134,3 @@ def indexes(db=None):
         salt '*' sqlite3.indexes /root/test.db
     '''
     return indices(db)
-
