@@ -30,9 +30,9 @@ def doc(module=''):
 
     CLI Example::
 
-        salt \* sys.doc
-        salt \* sys.doc sys
-        salt \* sys.doc sys.doc
+        salt '*' sys.doc
+        salt '*' sys.doc sys
+        salt '*' sys.doc sys.doc
     '''
     docs = {}
     if module:
@@ -54,8 +54,8 @@ def list_functions(module=''):
 
     CLI Example::
 
-        salt \* sys.list_functions
-        salt \* sys.list_functions sys
+        salt '*' sys.list_functions
+        salt '*' sys.list_functions sys
     '''
     names = set()
     if module:
@@ -74,7 +74,7 @@ def list_modules():
 
     CLI Example::
 
-        salt \* sys.list_modules
+        salt '*' sys.list_modules
     '''
     modules = set()
     for func in __salt__:
@@ -91,7 +91,7 @@ def reload_modules():
 
     CLI Example::
 
-        salt \* sys.reload_modules
+        salt '*' sys.reload_modules
     '''
     # This is handled inside the minion.py file, the function is caught before
     # it ever gets here
