@@ -26,7 +26,7 @@ def get_enabled():
     '''
     ret = set()
     services = []
-    cmd = 'sc query type= service'
+    cmd = 'sc query type= service state= all'
     lines = __salt__['cmd.run'](cmd).splitlines()
     for line in lines:
         if 'SERVICE_NAME:' in line:
@@ -53,7 +53,7 @@ def get_disabled():
     '''
     ret = set()
     services = []
-    cmd = 'sc query type= service'
+    cmd = 'sc query type= service state= all'
     lines = __salt__['cmd.run'](cmd).splitlines()
     for line in lines:
         if 'SERVICE_NAME:' in line:
@@ -82,6 +82,51 @@ def get_all():
     '''
     return sorted(get_enabled() + get_disabled())
 
+def get_service_name(*args):
+    '''
+    The Display Name is what is displayed in Windows when services.msc is
+    executed.  Each Display Name has an associated Service Name which is the
+    actual name of the service.  This function allows you to discover the
+    Service Name by returning a dictionary of Display Names and Service Names,
+    or filter by adding arguments of Display Names.
+
+    If no args are passed, return a dict of all services where the keys are the
+    service Display Names and the values are the Service Names.
+
+    If arguments are passed, create a dict of Display Names and Service Names
+
+    CLI Example::
+
+        salt '*' service.get_service_name
+
+        salt '*' service.get_service_name 'Google Update Service (gupdate)' 'DHCP Client'
+    '''
+    ret = {}
+    services = []
+    display_names = []
+    cmd = 'sc query type= service state= all'
+    lines = __salt__['cmd.run'](cmd).splitlines()
+    for line in lines:
+        if 'SERVICE_NAME:' in line:
+            comps = line.split(':', 1)
+            if not len(comps) > 1:
+                continue
+            services.append(comps[1].strip())
+        if 'DISPLAY_NAME:' in line:
+            comps = line.split(':', 1)
+            if not len(comps) > 1:
+                continue
+            display_names.append(comps[1].strip())
+    if len(services) == len(display_names):
+        service_dict = dict(zip(display_names, services))
+    else:
+        return 'Service Names and Display Names mismatch'
+    if len(args) == 0:
+        return service_dict
+    for arg in args:
+        if arg in service_dict:
+            ret[arg] = service_dict[arg]
+    return ret
 
 def start(name):
     '''
