@@ -15,7 +15,18 @@ def __virtual__():
     return 'user' if __grains__['kernel'] == 'Windows' else False
 
 
-def add(name, uid=None, gid=None, groups=None, home=False, shell=None, system=False):
+def add(name,
+        uid=None,
+        gid=None,
+        groups=None,
+        home=False,
+        shell=None,
+        unique=False,
+        system=False,
+        fullname=False,
+        roomnumber=False,
+        workphone=False,
+        homephone=False):
     '''
     Add a user to the minion
 
@@ -29,9 +40,10 @@ def add(name, uid=None, gid=None, groups=None, home=False, shell=None, system=Fa
     return not ret['retcode']
 
 
-def delete(name):
+def delete(name, purge=False, force=False):
     '''
     Remove a user from the minion
+    NOTE: purge and force have not been implemented on Windows yet
 
     CLI Example::
 
@@ -136,6 +148,26 @@ def chprofile(name, profile):
         return post_info['profile'] == profile
     return False
 
+def chfullname(name, fullname):
+    '''
+    Change the full name of the user
+
+    CLI Example::
+
+        salt '*' user.chfullname user 'First Last'
+    '''
+    pre_info = info(name)
+    if not pre_info:
+        return False
+    if fullname == pre_info['fullname']:
+        return True
+    cmd = 'net user {0} /fullname:"{1}"'.format(name, fullname)
+    __salt__['cmd.run'](cmd)
+    post_info = info(name)
+    if post_info['fullname'] != pre_info['fullname']:
+        return post_info['fullname'] == fullname
+    return False
+
 
 def chgroups(name, groups, append=False):
     '''
@@ -183,7 +215,7 @@ def info(name):
                 continue
             items[comps[0].strip()] = comps[1].strip()
     grouplist = []
-    groups = items['Local Group Memberships'].split(' ')
+    groups = items['Local Group Memberships'].split('  ')
     for group in groups:
         if not group:
             continue
@@ -197,6 +229,7 @@ def info(name):
     ret['profile'] = items['User profile']
     ret['home'] = items['Home directory']
     ret['groups'] = grouplist
+    ret['gid'] = ''
 
     return ret
 
