@@ -1,6 +1,7 @@
+# Import python libs
 from StringIO import StringIO
 
-# Import Salt libs
+# Import salt libs
 from salt.exceptions import SaltRenderError
 import salt.utils.templates
 
@@ -18,7 +19,8 @@ def render(template_file, env='', sls='', argline='', context=None, **kws):
             pillar=__pillar__,
             env=env,
             sls=sls,
-            context=context)
+            context=context,
+            **kws)
     if not tmp_data.get('result', False):
         raise SaltRenderError(tmp_data.get('data',
             'Unknown render error in the wempy renderer'))
