@@ -22,7 +22,7 @@ Use the following mysql database schema::
       DEFAULT CHARACTER SET utf8
       DEFAULT COLLATE utf8_general_ci;
 
-    USE `salt`;
+    USE `salt`;  
 
     --
     -- Table structure for table `jids`
@@ -57,27 +57,29 @@ Required python modules: MySQLdb
 
 # Import python libs
 from contextlib import contextmanager
-import json, sys
+import sys
+import json
 
 # Import third party libs
 try:
-    import MySQLdb 
-    has_mysql = True
+    import MySQLdb
+    HAS_MYSQL = True
 except ImportError:
-    has_mysql = False
+    HAS_MYSQL = False
 
 
 def __virtual__():
-    if not has_mysql:
+    if not HAS_MYSQL:
         return False
     return 'mysql'
 
+
 @contextmanager
 def _get_serv(commit=False):
     '''
     Return a mysql cursor
     '''
-    conn =  MySQLdb.connect(
+    conn = MySQLdb.connect(
             host=__salt__['config.option']('mysql.host'),
             user=__salt__['config.option']('mysql.user'),
             passwd=__salt__['config.option']('mysql.pass'),
@@ -107,11 +109,11 @@ def returner(ret):
     '''
     with _get_serv(commit=True) as cur:
 
-        sql = '''INSERT INTO `salt`.`salt_returns`
+        sql = '''INSERT INTO `salt_returns`
                 (`fun`, `jid`, `return`, `id`, `success`, `full_ret` )
                 VALUES (%s, %s, %s, %s, %s, %s)'''
-        cur.execute(sql, (ret['fun'], ret['jid'], 
-                            str(ret['return']), ret['id'], 
+        cur.execute(sql, (ret['fun'], ret['jid'],
+                            str(ret['return']), ret['id'],
                             ret['success'], json.dumps(ret)))
 
 
@@ -120,8 +122,8 @@ def save_load(jid, load):
     Save the load to the specified jid id
     '''
     with _get_serv(commit=True) as cur:
-        
-        sql = '''INSERT INTO `salt`.`jids`
+
+        sql = '''INSERT INTO `jids`
                (`jid`, `load`)
                 VALUES (%s, %s)'''
 
@@ -134,7 +136,7 @@ def get_load(jid):
     '''
     with _get_serv(commit=True) as cur:
 
-        sql = '''SELECT load FROM `salt`.`jids`
+        sql = '''SELECT load FROM `jids`
                 WHERE `jid` = '%s';'''
 
         cur.execute(sql, (jid,))
@@ -150,9 +152,9 @@ def get_jid(jid):
     '''
     with _get_serv(commit=True) as cur:
 
-        sql = '''SELECT id, full_ret FROM `salt`.`salt_returns`
+        sql = '''SELECT id, full_ret FROM `salt_returns`
                 WHERE `jid` = %s'''
-        
+
         cur.execute(sql, (jid,))
         data = cur.fetchall()
         ret = {}
@@ -169,13 +171,13 @@ def get_fun(fun):
     with _get_serv(commit=True) as cur:
 
         sql = '''SELECT s.id,s.jid, s.full_ret
-                FROM `salt`.`salt_returns` s
-                JOIN ( SELECT MAX(`jid`) as jid 
-                    from `salt`.`salt_returns` GROUP BY fun, id) max
+                FROM `salt_returns` s
+                JOIN ( SELECT MAX(`jid`) as jid
+                    from `salt_returns` GROUP BY fun, id) max
                 ON s.jid = max.jid
                 WHERE s.fun = %s
                 '''
-        
+
         cur.execute(sql, (fun,))
         data = cur.fetchall()
 
@@ -185,6 +187,7 @@ def get_fun(fun):
                 ret[minion] = json.loads(full_ret)
         return ret
 
+
 def get_jids():
     '''
     Return a list of all job ids
@@ -192,7 +195,7 @@ def get_jids():
     with _get_serv(commit=True) as cur:
 
         sql = '''SELECT DISTINCT jid
-                FROM `salt`.`jids`'''
+                FROM `jids`'''
 
         cur.execute(sql)
         data = cur.fetchall()
@@ -202,15 +205,14 @@ def get_jids():
         return ret
 
 
-
 def get_minions():
     '''
     Return a list of minions
     '''
     with _get_serv(commit=True) as cur:
 
-        sql = '''SELECT DISTINCT id 
-                FROM `salt`.`salt_returns`'''
+        sql = '''SELECT DISTINCT id
+                FROM `salt_returns`'''
 
         cur.execute(sql)
         data = cur.fetchall()
