@@ -24,6 +24,8 @@ def genrepo():
     '''
     ret = {}
     repo = __opts__['win_repo']
+    if not os.path.exists(repo):
+        os.makedirs(repo)
     winrepo = __opts__['win_repo_mastercachefile']
     for root, dirs, files in os.walk(repo):
         for name in files:
