@@ -39,7 +39,7 @@ def present(name,
 
     password_hash
         The password in hashed form. Be sure to quote the password because
-        YAML does't like the ``*``::
+        YAML doesn't like the ``*``::
 
             SELECT PASSWORD('mypass') ==> *6C8989366EAF75BB670AD8EA7A7FC1176A95CEF4
     '''
