@@ -42,13 +42,13 @@ def present(name,
         Should the new group be allowed to initiate streaming replication
 
     password
-        The group's pasword
+        The group's password
 
     groups
         A string of comma separated groups the group should be in
 
     runas
-        System user all operation should be preformed on behalf of
+        System user all operations should be performed on behalf of
     '''
     ret = {'name': name,
            'changes': {},
@@ -90,7 +90,7 @@ def absent(name, runas=None):
         The groupname of the group to remove
 
     runas
-        System user all operation should be preformed on behalf of
+        System user all operations should be performed on behalf of
     '''
     ret = {'name': name,
            'changes': {},
