@@ -52,14 +52,29 @@ def running(name,
     runas
         Name of the user to run the supervisorctl command
     '''
-    ret = {'name': name, 'result': True, 'comment': '', 'changes': ''}
+    ret = {'name': name, 'result': True, 'comment': '', 'changes': {}}
+
+    all_processes = __salt__['supervisord.status'](user=runas)
+    needs_update = name not in all_processes
 
     if __opts__['test']:
         ret['result'] = None
         _msg = 'restarted' if restart else 'started'
+        _update = ', but service needs to be added' if needs_update else ''
         ret['comment'] = (
-            'Service {0} is set to be {1}'.format(
-                name, _msg))
+            'Service {0} is set to be {1}{2}'.format(
+                name, _msg, _update))
+        return
+
+    if needs_update:
+        comment = 'Adding service: {0}'.format(name)
+        __salt__['supervisord.reread'](user=runas)
+        result = __salt__['supervisord.add'](name, user=runas)
+
+        ret.update(_check_error(result, comment))
+        ret['changes']['update'] = comment
+        log.debug(comment)
+
     elif restart:
         comment = 'Restarting service: {0}'.format(name)
         log.debug(comment)
@@ -67,8 +82,15 @@ def running(name,
 
         ret.update(_check_error(result, comment))
 
+    elif name in all_processes and all_processes[name]['state'] == 'RUNNING':
+        comment = 'Not starting already running service: {0}'.format(name)
+        result = comment
+
+        ret.update({'comment': comment})
+
     else:
         comment = 'Starting service: {0}'.format(name)
+        ret['changes']['start'] = comment
         log.debug(comment)
         result = __salt__['supervisord.start'](name, user=runas)
 
@@ -77,7 +99,6 @@ def running(name,
     log.debug(unicode(result))
     return ret
 
-
 def dead(name,
          runas=None):
     '''
