@@ -40,7 +40,6 @@ def _changes(name,
              password=None,
              enforce_password=True,
              shell=None,
-             unique=True,
              fullname='',
              roomnumber='',
              workphone='',
@@ -50,7 +49,7 @@ def _changes(name,
     otherwise return False.
     '''
 
-    if not __grains__['os'] in ('FreeBSD', 'OpenBSD'):
+    if __grains__['os'] not in ('FreeBSD', 'OpenBSD'):
         lshad = __salt__['shadow.info'](name)
 
     lusr = __salt__['user.info'](name)
@@ -66,14 +65,14 @@ def _changes(name,
         if lusr['gid'] not in (gid, __salt__['file.group_to_gid'](gid)):
             change['gid'] = gid
     # remove the default group from the list for comparison purposes
-    if __salt__['file.gid_to_group'](gid or lusr['gid']) in \
+    if gid and __salt__['file.gid_to_group'](gid or lusr['gid']) in \
             lusr['groups']:
         lusr['groups'].remove(
             __salt__['file.gid_to_group'](gid or lusr['gid'])
         )
     # remove default group from wanted_groups, as this requirement is
     # already met
-    if __salt__['file.gid_to_group'](gid or lusr['gid']) in \
+    if gid and __salt__['file.gid_to_group'](gid or lusr['gid']) in \
             wanted_groups:
         wanted_groups.remove(
             __salt__['file.gid_to_group'](gid or lusr['gid']))
@@ -83,19 +82,19 @@ def _changes(name,
                 change['groups'] = wanted_groups
         else:
             for wanted_group in wanted_groups:
-                if not wanted_group in lusr['groups']:
-                    if not groups in change:
+                if wanted_group not in lusr['groups']:
+                    if 'groups' not in change:
                         change['groups'] = []
                     change['groups'].append(wanted_group)
     if home:
         if lusr['home'] != home:
-            if not home is True:
+            if home is not True:
                 change['home'] = home
     if shell:
         if lusr['shell'] != shell:
             change['shell'] = shell
     if password:
-        if not __grains__['os'] in ('FreeBSD', 'OpenBSD'):
+        if __grains__['os'] not in ('FreeBSD', 'OpenBSD'):
             if lshad['pwd'] == '!' or \
                     lshad['pwd'] != '!' and enforce_password:
                 if lshad['pwd'] != password:
@@ -248,7 +247,6 @@ def present(name,
                        password,
                        enforce_password,
                        shell,
-                       unique,
                        fullname,
                        roomnumber,
                        workphone,
@@ -282,14 +280,14 @@ def present(name,
 
         post = __salt__['user.info'](name)
         spost = {}
-        if not __grains__['os'] in ('FreeBSD', 'OpenBSD'):
+        if __grains__['os'] not in ('FreeBSD', 'OpenBSD'):
             if lshad['pwd'] != password:
                 spost = __salt__['shadow.info'](name)
         # See if anything changed
         for key in post:
             if post[key] != pre[key]:
                 ret['changes'][key] = post[key]
-        if not __grains__['os'] in ('FreeBSD', 'OpenBSD'):
+        if __grains__['os'] not in ('FreeBSD', 'OpenBSD'):
             for key in spost:
                 if lshad[key] != spost[key]:
                     ret['changes'][key] = spost[key]
@@ -305,7 +303,6 @@ def present(name,
                            password,
                            enforce_password,
                            shell,
-                           unique,
                            fullname,
                            roomnumber,
                            workphone,
@@ -365,7 +362,7 @@ def absent(name, purge=False, force=False):
         The name of the user to remove
 
     purge
-        Set purge to delete all of the user's file as well as the user
+        Set purge to delete all of the user's files as well as the user
 
     force
         If the user is logged in the absent state will fail, set the force
