@@ -36,7 +36,7 @@ __opts__ = {'cobbler.url': 'http://localhost/cobbler_api',
 
 def top(**kwargs):
     '''
-    Look up top data in Cobbler for for a minion.
+    Look up top data in Cobbler for a minion.
     '''
     url = __opts__['cobbler.url']
     user = __opts__['cobbler.user']
@@ -48,7 +48,7 @@ def top(**kwargs):
     try:
         server = xmlrpclib.Server(url, allow_none=True)
         if user:
-            server = (server, server.login(user, password))
+            server = xmlrpclib.Server(server, server.login(user, password))
         data = server.get_blended_data(None, minion_id)
     except Exception:
         log.exception(
