@@ -25,9 +25,6 @@ import subprocess
 # Import third party libs
 import yaml
 
-# Import Salt libs
-import salt.utils
-
 
 def __virtual__():
     '''
@@ -54,7 +51,6 @@ def top(**kwargs):
                 shell=True,
                 stdout=subprocess.PIPE
                 ).communicate()[0])
-    print ndata
     ret = {}
     if 'environment' in ndata:
         env = ndata['environment']
