@@ -35,7 +35,7 @@ def zmq_version():
     ver = zmq.__version__
     # The last matched group can be None if the version
     # is something like 3.1 and that will work properly
-    match = re.match('^(\d+)\.(\d+)(?:\.(\d+))?', ver)
+    match = re.match(r'^(\d+)\.(\d+)(?:\.(\d+))?', ver)
 
     # Fallthrough and hope for the best
     if not match:
@@ -208,7 +208,7 @@ def verify_env(dirs, user, permissive=False, pki_dir=''):
         # If starting the process as root, chown the new dirs
         if os.getuid() == 0:
             fmode = os.stat(dir_)
-            if not fmode.st_uid == uid or not fmode.st_gid == gid:
+            if fmode.st_uid != uid or fmode.st_gid != gid:
                 if permissive and fmode.st_gid in groups:
                     # Allow the directory to be owned by any group root
                     # belongs to if we say it's ok to be permissive
@@ -227,7 +227,7 @@ def verify_env(dirs, user, permissive=False, pki_dir=''):
                         fmode = os.stat(path)
                     except (IOError, OSError):
                         pass
-                    if not fmode.st_uid == uid or not fmode.st_gid == gid:
+                    if fmode.st_uid != uid or fmode.st_gid != gid:
                         if permissive and fmode.st_gid in groups:
                             pass
                         else:
@@ -236,7 +236,7 @@ def verify_env(dirs, user, permissive=False, pki_dir=''):
                 for name in dirs:
                     path = os.path.join(root, name)
                     fmode = os.stat(path)
-                    if not fmode.st_uid == uid or not fmode.st_gid == gid:
+                    if fmode.st_uid != uid or fmode.st_gid != gid:
                         if permissive and fmode.st_gid in groups:
                             pass
                         else:
@@ -348,6 +348,9 @@ def check_path_traversal(path, user='root'):
 
 
 def check_max_open_files(opts):
+    '''
+    Check the number of max allowed open files and adjust if needed
+    '''
     mof_c = opts.get('max_open_files', 100000)
     if sys.platform.startswith('win'):
         # Check the Windows API for more detail on this
@@ -406,3 +409,30 @@ def check_max_open_files(opts):
 
     msg += 'Please consider raising this value.'
     log.log(level=level, msg=msg)
+
+
+def clean_path(root, path, subdir=False):
+    '''
+    Accepts the root the path needs to be under and verifies that the path is
+    under said root. Pass in subdir=True if the path can result in a
+    subdirectory of the root instead of having to reside directly in the root
+    '''
+    if not os.path.isabs(root):
+        return ''
+    if not os.path.isabs(path):
+        path = os.path.join(root, path)
+    path = os.path.normpath(path)
+    if subdir:
+        if path.startswith(root):
+            return path
+    else:
+        if os.path.dirname(path) == os.path.normpath(root):
+            return path
+    return ''
+
+
+def valid_id(id_):
+    '''
+    Returns if the passed id is valid
+    '''
+    return bool(clean_path('/etc/pki/salt/master', id_))
