@@ -2,8 +2,10 @@
 Wheel system wrapper for key system
 '''
 
+# Import salt libs
 import salt.key
 
+
 def list_all():
     '''
     List the keys under a named status
@@ -23,7 +25,7 @@ def delete(match):
     Delete keys based on a glob match
     '''
     skey = salt.key.Key(__opts__)
-    return skey.delete(match)
+    return skey.delete_key(match)
 
 def reject(match):
     '''
