@@ -16,7 +16,7 @@ class SupervisordModuleTest(integration.ModuleCase):
         if not ret:
             self.skipTest('Supervisor not installed')
         if os.geteuid() != 0:
-            self.skipTest('You must be this root to run this test')
+            self.skipTest('You must be root to run this test')
 
     def test_start_all(self):
         '''
@@ -65,7 +65,7 @@ class SupervisordModuleTest(integration.ModuleCase):
         status all services
         '''
         ret = self.run_function('supervisord.status', [])
-        self.assertEqual(ret, '')
+        self.assertEqual(ret, {})
 
     def test_status_one(self):
         '''
