@@ -1,11 +1,6 @@
 # Import python libs
 import os
-import sys
-
-# Import salt libs
-from saltunittest import TestLoader, TextTestRunner
 import integration
-from integration import TestDaemon
 
 
 class TestModuleTest(integration.ModuleCase):
@@ -94,10 +89,7 @@ class TestModuleTest(integration.ModuleCase):
         '''
         self.assertEqual(self.run_function('test.outputter', ['text']), 'text')
 
-if __name__ == "__main__":
-    loader = TestLoader()
-    tests = loader.loadTestsFromTestCase(TestModuleTest)
-    print('Setting up Salt daemons to execute tests')
-    with TestDaemon():
-        runner = TextTestRunner(verbosity=1).run(tests)
-        sys.exit(runner.wasSuccessful())
+
+if __name__ == '__main__':
+    from integration import run_tests
+    run_tests(TestModuleTest)
