@@ -37,12 +37,12 @@ class KeyTest(integration.ShellCase,
         '''
         test salt-key -L --json-out
         '''
-        data = self.run_key('-L --json-out')
-        if version.__version_info__ < (0, 10, 8):
-            self.assertEqual(
-                "WARNING: The option --json-out is deprecated. Please "
-                "consider using '--out json' instead.",
-                data[0]
+        data = self.run_key('-L --json-out', catch_stderr=True)
+        if version.__version_info__ >= (0, 12):
+            self.assertIn(
+                'salt-key: error: The option --json-out was deprecated. '
+                'Please use \'--out json\' instead.',
+                data[1]
             )
 
         data = self.run_key('-L --out json')
@@ -56,19 +56,19 @@ class KeyTest(integration.ShellCase,
             '        "sub_minion"',
             '    ]',
             '}',
-            ]
+        ]
         self.assertEqual(data, expect)
 
     def test_list_yaml_out(self):
         '''
         test salt-key -L --yaml-out
         '''
-        data = self.run_key('-L --yaml-out')
-        if version.__version_info__ < (0, 10, 8):
-            self.assertEqual(
-                "WARNING: The option --yaml-out is deprecated. Please "
-                "consider using '--out yaml' instead.",
-                data[0]
+        data = self.run_key('-L --yaml-out', catch_stderr=True)
+        if version.__version_info__ >= (0, 12):
+            self.assertIn(
+                'salt-key: error: The option --yaml-out was deprecated. '
+                'Please use \'--out yaml\' instead.',
+                data[1]
             )
 
         data = self.run_key('-L --out yaml')
@@ -86,12 +86,12 @@ class KeyTest(integration.ShellCase,
         '''
         test salt-key -L --raw-out
         '''
-        data = self.run_key('-L --raw-out')
-        if version.__version_info__ < (0, 10, 8):
-            self.assertEqual(
-                "WARNING: The option --raw-out is deprecated. Please "
-                "consider using '--out raw' instead.",
-                data[0]
+        data = self.run_key('-L --raw-out', catch_stderr=True)
+        if version.__version_info__ >= (0, 12):
+            self.assertIn(
+                'salt-key: error: The option --raw-out was deprecated. '
+                'Please use \'--out raw\' instead.',
+                data[1]
             )
 
         data = self.run_key('-L --out raw')
