@@ -3,6 +3,7 @@ Tests for the Git state
 '''
 import os
 import shutil
+import socket
 import integration
 
 
@@ -11,6 +12,18 @@ class GitTest(integration.ModuleCase, integration.SaltReturnAssertsMixIn):
     Validate the git state
     '''
 
+    def setUp(self):
+        super(GitTest, self).setUp()
+        self.__domain = 'github.com'
+        try:
+            if hasattr(socket, 'setdefaulttimeout'):
+                # 10 second dns timeout
+                socket.setdefaulttimeout(10)
+            socket.gethostbyname(self.__domain)
+        except socket.error:
+            msg = 'error resolving {0}, possible network issue?'
+            self.skipTest(msg.format(self.__domain))
+
     def test_latest(self):
         '''
         git.latest
@@ -19,7 +32,7 @@ class GitTest(integration.ModuleCase, integration.SaltReturnAssertsMixIn):
         try:
             ret = self.run_state(
                 'git.latest',
-                name='https://github.com/saltstack/salt.git',
+                name='https://{0}/saltstack/salt-bootstrap.git'.format(self.__domain),
                 rev='develop',
                 target=name,
                 submodules=True
@@ -57,7 +70,7 @@ class GitTest(integration.ModuleCase, integration.SaltReturnAssertsMixIn):
         try:
             ret = self.run_state(
                 'git.latest',
-                name='https://github.com/saltstack/salt.git',
+                name='https://{0}/saltstack/salt-bootstrap.git'.format(self.__domain),
                 rev='develop',
                 target=name,
                 submodules=True
@@ -67,36 +80,6 @@ class GitTest(integration.ModuleCase, integration.SaltReturnAssertsMixIn):
         finally:
             shutil.rmtree(name, ignore_errors=True)
 
-    def test_latest_recursive(self):
-        '''
-        git.latest
-        '''
-        name = os.path.join(integration.TMP, 'salt_repo')
-        try:
-            ret = self.run_state(
-                'git.latest',
-                name='https://github.com/mozilla/zamboni.git',
-                target=name,
-                submodules=True
-            )
-            self.assertSaltTrueReturn(ret)
-            self.assertTrue(
-                # with git 1.7.9.5, it's not a directory, it's a file with the
-                # contents:
-                #   gitdir: /tmp/salt-tests-tmpdir/salt_repo/.git/modules/vendor/modules/js/receiptverifier
-                #
-                # let's change it to exists!?!?!?
-                #
-                #os.path.isdir(
-                os.path.exists(
-                    os.path.join(
-                        name, 'vendor', 'js', 'receiptverifier', '.git'
-                    )
-                )
-            )
-        finally:
-            shutil.rmtree(name, ignore_errors=True)
-
     def test_present(self):
         '''
         git.present
