@@ -32,7 +32,7 @@ class StateMatchTest(integration.ModuleCase):
             ret
         )
 
-    @skipIf(os.geteuid() is not 0, 'you must be root to run this test')
+    @skipIf(os.geteuid() != 0, 'you must be root to run this test')
     def test_issue_2167_ipcidr_no_AttributeError(self):
         subnets = self.run_function('network.subnets')
         self.assertTrue(len(subnets) > 0)
