@@ -1,15 +1,20 @@
 # -*- coding: utf-8 -*-
-"""
-    tests.unit.config
-    ~~~~~~~~~~~~~~~~~
+'''
+    tests.unit.config_test
+    ~~~~~~~~~~~~~~~~~~~~~~
 
-    :copyright: © 2012 UfSoft.org - :email:`Pedro Algarvio (pedro@algarvio.me)`
+    :codeauthor: :email:`Pedro Algarvio (pedro@algarvio.me)`
+    :copyright: © 2012 by the SaltStack Team, see AUTHORS for more details.
     :license: Apache 2.0, see LICENSE for more details.
-"""
+'''
 
+# Import python libs
 import os
 import shutil
 import tempfile
+
+# Import salt libs
+import salt.utils
 from saltunittest import TestCase, TestLoader, TextTestRunner
 from salt import config as sconfig
 
@@ -17,7 +22,7 @@ from salt import config as sconfig
 class ConfigTestCase(TestCase):
     def test_proper_path_joining(self):
         fpath = tempfile.mktemp()
-        open(fpath, 'w').write(
+        salt.utils.fopen(fpath, 'w').write(
             "root_dir: /\n"
             "key_logfile: key\n"
         )
@@ -32,7 +37,7 @@ class ConfigTestCase(TestCase):
         root_dir = os.path.join(tempdir, 'foo', 'bar')
         os.makedirs(root_dir)
         fpath = os.path.join(root_dir, 'config')
-        open(fpath, 'w').write(
+        salt.utils.fopen(fpath, 'w').write(
             'root_dir: {0}\n'
             'log_file: {1}\n'.format(root_dir, fpath)
         )
